@@ -1,4 +1,5 @@
 import json
+import sys
 
 import click
 import requests
@@ -67,7 +68,7 @@ def run(object_name: str):
         print_err(f"The object {object_name!r} doesn't exist. Make sure you wrote it correctly or create it using the"
                   f" `aliot new` command.")
 
-    Popen(["python", obj_path]).communicate()
+    Popen([sys.executable, obj_path]).communicate()
 
 
 @main.group()
